package com.ztmap.project.zhny.netswdl.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ztmap.project.zhny.netswdl.mapper.TNetSwdlMapper;
import com.ztmap.project.zhny.netswdl.domain.TNetSwdl;
import com.ztmap.project.zhny.netswdl.service.ITNetSwdlService;
import com.ztmap.common.utils.text.Convert;

/**
 * 上网电量Service业务层处理
 * 
 * @author ztmap
 * @date 2023-11-16
 */
@Service
public class TNetSwdlServiceImpl implements ITNetSwdlService 
{
    @Autowired
    private TNetSwdlMapper tNetSwdlMapper;

    /**
     * 查询上网电量
     * 
     * @param id 上网电量ID
     * @return 上网电量
     */
    @Override
    public TNetSwdl selectTNetSwdlById(Long id)
    {
        return tNetSwdlMapper.selectTNetSwdlById(id);
    }

    /**
     * 查询上网电量列表
     * 
     * @param tNetSwdl 上网电量
     * @return 上网电量
     */
    @Override
    public List<TNetSwdl> selectTNetSwdlList(TNetSwdl tNetSwdl)
    {
        return tNetSwdlMapper.selectTNetSwdlList(tNetSwdl);
    }

    /**
     * 新增上网电量
     * 
     * @param tNetSwdl 上网电量
     * @return 结果
     */
    @Override
    public int insertTNetSwdl(TNetSwdl tNetSwdl)
    {
        return tNetSwdlMapper.insertTNetSwdl(tNetSwdl);
    }

    /**
     * 修改上网电量
     * 
     * @param tNetSwdl 上网电量
     * @return 结果
     */
    @Override
    public int updateTNetSwdl(TNetSwdl tNetSwdl)
    {
        return tNetSwdlMapper.updateTNetSwdl(tNetSwdl);
    }

    /**
     * 删除上网电量对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteTNetSwdlByIds(String ids)
    {
        return tNetSwdlMapper.deleteTNetSwdlByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除上网电量信息
     * 
     * @param id 上网电量ID
     * @return 结果
     */
    @Override
    public int deleteTNetSwdlById(Long id)
    {
        return tNetSwdlMapper.deleteTNetSwdlById(id);
    }
}
